==> haskell-entropy-0.4.1.1-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-entropy.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: entropy
version: 0.4.1.1
id: entropy-0.4.1.1-FmBdJKRG6hQDsYzBhT7c6v
key: entropy-0.4.1.1-FmBdJKRG6hQDsYzBhT7c6v
license: BSD-3-Clause
copyright: Thomas DuBuisson <thomas.dubuisson@gmail.com>
maintainer: Thomas DuBuisson <thomas.dubuisson@gmail.com>
author: Thomas DuBuisson <thomas.dubuisson@gmail.com>
stability: stable
homepage: https://github.com/TomMD/entropy
synopsis: A platform independent entropy source
description:
    A platform independent method to obtain cryptographically strong entropy
    (RDRAND, urandom, CryptAPI, and patches welcome)
    Users looking for cryptographically strong (number-theoretically
    sound) PRNGs should see the '\''DRBG'\'' package too.
category: Data, Cryptography
abi: bbba9b47b66235cbe49005ce0f2ca1a5
exposed: True
exposed-modules:
    System.Entropy
hidden-modules: System.EntropyNix
import-dirs: /usr/lib/ghc-8.4.3/site-local/entropy-0.4.1.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/entropy-0.4.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/entropy-0.4.1.1
hs-libraries: HSentropy-0.4.1.1-FmBdJKRG6hQDsYzBhT7c6v
depends:
    base-4.11.1.0 bytestring-0.10.8.2 unix-2.7.2.2
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             unix-2.7.2.2=f81aa481840dadf9c364a1cea96978c0
haddock-interfaces: /usr/share/doc/haskell-entropy/html/entropy.haddock
haddock-html: /usr/share/doc/haskell-entropy/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-entropy-0.4.1.3-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-entropy.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: entropy
version: 0.4.1.3
id: entropy-0.4.1.3-DgdrwWh8SPxKScPoc17aKl
key: entropy-0.4.1.3-DgdrwWh8SPxKScPoc17aKl
license: BSD-3-Clause
copyright: Thomas DuBuisson <thomas.dubuisson@gmail.com>
maintainer: Thomas DuBuisson <thomas.dubuisson@gmail.com>
author: Thomas DuBuisson <thomas.dubuisson@gmail.com>
stability: stable
homepage: https://github.com/TomMD/entropy
synopsis: A platform independent entropy source
description:
    A mostly platform independent (not GHCJS) method to obtain cryptographically strong entropy
    (RDRAND, urandom, CryptAPI, and patches welcome)
    Users looking for cryptographically strong (number-theoretically
    sound) PRNGs should see the '\''DRBG'\'' package too.
category: Data, Cryptography
abi: f8adc9fd931aa49b6a2a7e2785fb0c69
exposed: True
exposed-modules:
    System.Entropy
hidden-modules: System.EntropyNix
import-dirs: /usr/lib/ghc-8.4.3/site-local/entropy-0.4.1.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/entropy-0.4.1.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/entropy-0.4.1.3
hs-libraries: HSentropy-0.4.1.3-DgdrwWh8SPxKScPoc17aKl
depends:
    base-4.11.1.0 bytestring-0.10.8.2 unix-2.7.2.2
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             unix-2.7.2.2=f81aa481840dadf9c364a1cea96978c0
haddock-interfaces: /usr/share/doc/haskell-entropy/html/entropy.haddock
haddock-html: /usr/share/doc/haskell-entropy/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
